%% [coef, A, SSE] = mypolyfit(x, y, d)
% An implementation of least squares polynomial fitting. It is a modified
% version of MatLab builtin 'polyfit'.
%
% Input:
% x,y: column vectors of equal size
% d: required polynomial degree plus one (number of coefficients)
%
% Output:
% coef: the d least squares coefficients
% A: intermediate value returned to allow fast evaluation in mypolyval
% SSE: sum of squared errors
%
function [coef, A, SSE] = mypolyfit (x, y, d)
  X = vandermonde(x, d);
  A = pinv(X' * X);
  coef = A * (X' * y); % pseudoinverse has the property pinv(X) = pinv(X'*X)*X'
  SSE = sum((X * coef - y).^2);
end
