%% PFS
% An abstract class modelling a prequential forecasting system.
%
classdef PFS < handle
    
    methods (Abstract)
        
        %% predict(x)
        % Returns the probability of observing x
        p = predict(this, x)

        %% process(x)
        % Updates the inner state of the PFS with the given observation
        process(this, x)
        
        %% clone()
        % Returns a clone of this PFS, which is used to implement
        % "freezing" strategies for the slow and fast switch distributions.
        PFS = clone(this);
    end
   
    methods
        %% predict_and_process(x)
        % predicts x then processes it
        function p = predict_and_process(this, x)
            p = this.predict(x);
            this.process(x);
        end
    end
    
end
